# Evalica

[![Tests][github_tests_badge]][github_tests_link] 

[github_tests_badge]: https://github.com/dustalov/evalica/actions/workflows/test.yml/badge.svg?branch=master
[github_tests_link]: https://github.com/dustalov/evalica/actions/workflows/test.yml

Evalica, your favourite evaluation toolkit.

- [Tutorial.ipynb](Tutorial.ipynb)

![Evalica](Evalica.svg)
